@@ -4,6 +4,7 @@ import logging
 
 import socketio
 import ujson as ujson
+from multiprocessing.dummy import Pool
 
 
 class GSCNodeFunctionReceiverSocket:
@@ -12,16 +13,25 @@ class GSCNodeFunctionReceiverSocket:
         self = GSCNodeFunctionReceiverSocket()
         self.sio = sio
         self.gsdbs = gsdbs
+        self._pool = Pool(self._gsdbs.credentials["poolsize"])
         self.oncnodefunction = oncnodefunction
         self._logger = logging.getLogger(__name__)
 
+        def on_success(r):
+            self._logger.info('cnodefunction succeed')
+
+        def on_errorPost(error):
+            self._logger.exception('cnodefunction failed :' + error)
+
         @self.sio.event
         def connect():
             self._logger.info('oncnodefunction connected')
 
         @self.sio.event
         def oncnodefunction(id, msg):
-            self.oncnodefunction(self.gsdbs, id, ujson.loads(msg))
+            self._pool.apply_async(self.oncnodefunction, args=[self.gsdbs, id, ujson.loads(msg)], callback=on_success,
+                                   error_callback=on_errorPost)
+            # self.oncnodefunction(self.gsdbs, id, ujson.loads(msg))
 
         connectURL = ""
 
